<?php
/*
+-----------------------------------------------------------
|  BirdBoard v1.0.0 Beta
|  $Id: mysql.class.php,v 1.11 2005/07/01 00:15:18 user00265 Exp $
|  ===========================
|  Developers: Michael Swiger <mokkan@users.sourceforge.net>
|              Elisamuel Resto <user00265@users.sourceforge.net>
|              relpats_eht <relpats_eht@users.sourceforge.net>
|  Site: http://www.birdboard.org
|  Copyright (c)2004-2005 BirdBoard Devs
|
|  ===========================
|  This program is free software; you can redistribute it and/or modify
|  it under the terms of the GNU General Public License as published by
|  the Free Software Foundation; either version 2 of the License, or
|  (at your option) any later version.
+-----------------------------------------------------------
*/


class MySQL {
    // Global connection parameters
    var $hostname = "";
    var $username = "";
    var $password = "";
    var $database = "";
    var $pconnect = false;

    // Global script parameters
    var $sql_link = false;
    var $counter  = 0;
    var $query    = "";
    var $result   = false;
    var $exects   = 0;
    var $exectime = 0;

    // Error handling variables
    var $error    = false;
    var $err_desc = "";
    var $err_type = 0;

    // Timer functions
    function startTimer() {
        $this->exects = explode(" ", microtime());
        $this->exects = ($this->exects[1] + $this->exects[0]);
    }

    function stopTimer() {
        $exects = explode(" ", microtime());
        $exects = $exects[1] + $exects[0];
        $this->exectime += ($exects - $this->exects);
        return true;
    }
    function resetTimer() {
        $this->exects = 0;
        return true;
    }

    /*****************************************
     * @name MySQL                           *
     * @desc Initiate the mySQL connection   *
     *  parameters to ready the class for a  *
     *  mySQL connection for interaction.    *
     *****************************************/
    function MySQL($vars) {
        if (empty($vars['hostname'])) {
            $this->error = true;
            $this->err_type = 1;
            $this->err_desc = "Empty configuration variable for <i>\"hostname\"</i>. Please configure the system first.";
            $this->call_error();
        } else {
            $this->hostname = $vars['hostname'];
        }
        if (empty($vars['username'])) {
            $this->error = true;
            $this->err_type = 1;
            $this->err_desc = "Empty configuration variable for <i>\"username\"</i>. Please configure the system first.";
            $this->call_error();
        } else {
            $this->username = $vars['username'];
        }
        if (empty($vars['database'])) {
            $this->error = true;
            $this->err_type = 1;
            $this->err_desc = "Empty configuration variable for <i>\"database\"</i>. Please configure the system first.";
            $this->call_error();
        } else {
            $this->database = $vars['database'];
        }
        $this->password = $vars['password'];
        if (empty($vars['pconnect'])) {
            $this->pconnect = false;
        } else {
            $this->pconnect = $vars['pconnect'];
        }
    }

    /*****************************************
     * @name call_error                      *
     * @desc Trigger a error inside the      *
     *  class.                               *
     *****************************************/
    function call_error() {
    /*
     Here we handle the mySQL class errors, like
     empty variables and query/connection errors.

     To print SQL errors from a query or connection like:
     "You have a error in your SQL syntax near ..." or "Access denied for user@host"
     You would use something like this:
       $this->error = true;
       $this->err_type = 2;
       $this->call_error();

     If you want PHP to output a error like:
     "Fatal error: my custom  message here at /var/www/htdocs/script.php on line 12"
     you use the same as above, BUT, change the $this->err_type from 2 to 1 and set
     $this->err_desc with a custom error message (with HTML) for displaying.
    */
        if ($this->error == true) {
            switch($this->err_type) {
                default:
                case 1:
                    trigger_error($this->err_desc, E_USER_ERROR);
                break;
                case 2:
                    if (@mysql_errno($this->sql_link) > 0) {
                        $msg  = "<b>Error #".@mysql_errno($this->sql_link)."</b>: <em>".@mysql_error($this->sql_link)."</em>";
                        $msg .= "<br>\n<b>Query</b>:\n<br><textarea rows=\"10\" cols=\"60\" disabled>".implode(" ", explode(" ", $this->query))."</textarea>";
                        die($msg);
                    }
                break;
                case 3:
                    if ((@mysql_errno($this->sql_link) > 0) && (!empty($this->err_desc))) {
                        die($this->err_desc);
                    }
                break;
            }
        }
    }

    /*****************************************
     * @name connect                         *
     * @desc Use the class-defined vars to   *
     *  initiate a connection to the mySQL   *
     *  server for interaction.              *
     *****************************************/
    function connect() {
        if ($this->pconnect == true) {
            // Connect using a persistent socket
            ob_start();
            if ($this->sql_link = mysql_pconnect($this->hostname, $this->username, $this->password)) {
                $this->err_desc = ob_get_contents();
                ob_end_clean();
                if (mysql_select_db($this->database, $this->sql_link)) {
                    ob_end_clean();
                    return $this->sql_link;
                } else {
                    $this->err_desc = ob_get_contents();
                    ob_end_clean();
                    $this->error = true;
                    $this->err_type = 3;
                    $this->call_error();
                }
            } else {
                $this->err_desc = ob_get_contents();
                ob_end_clean();
                $this->error = true;
                $this->err_type = 3;
                $this->call_error();
            }
        } else {
            // Connect using a normal socket
            ob_start();
            if ($this->sql_link = mysql_connect($this->hostname, $this->username, $this->password)) {
                $this->err_desc = ob_get_contents();
                ob_end_clean();
                if (mysql_select_db($this->database, $this->sql_link)) {
                    ob_end_clean();
                    return $this->sql_link;
                } else {
                    $this->err_desc = ob_get_contents();
                    ob_end_clean();
                    $this->error = true;
                    $this->err_type = 3;
                    $this->call_error();
                }
            } else {
                $this->err_desc = ob_get_contents();
                ob_end_clean();
                $this->error = true;
                $this->err_type = 3;
                $this->call_error();
            }
        }
    }

    /*****************************************
     * @name counter                         *
     * @desc Returns the number of queries   *
     *  that have been made untill the point *
     *  that this function is called.        *
     *****************************************/
    function counter() {
        return $this->counter;
    }

    /*****************************************
     * @name getexectime                     *
     * @desc Returns the execution time of   *
     *  all the queries made to up to the    *
     *  point where the function is called.  *
     *****************************************/
    function getexectime() {
        return $this->exectime;
    }

    /*****************************************
     * @name query                           *
     * @desc Queries the active mySQL        *
     *  connection and returns the result to *
     *  the placeholder, or, returns false   *
     *  to that same placeholder if $rfalse  *
     *  is true.                             *
     *****************************************/
    function query($query, $rfalse = false, $dbi = false) {
        $dbi = ($dbi != false) ? $dbi : $this->sql_link;
        $this->query = $query;
        unset($this->result);
        $this->startTimer();
        if ($this->result = @mysql_query($this->query, $dbi)) {
            $this->stopTimer();
            $this->counter++;
            return $this->result;
        } else {
            $this->resetTimer();
            if ($rfalse == true) {
                return false;
            } else {
                $this->error = true;
                $this->err_type = 2;
                $this->call_error();
            }
        }
    }

    /*****************************************
     * @name fetch_array                      *
     * @desc Returns a named array from the   *
     *  mySQL query ran.                      *
     ******************************************/
    function fetch_array($res = "") {
        $res = (!isset($res) || empty($res)) ? $this->result : $res;
        if ($r = @mysql_fetch_assoc($res)) {
            return $r;
        } else {
            $this->error = 1;
            $this->err_type = 2;
            $this->call_error();
        }
    }

    /******************************************
     * @name num_rows                         *
     * @desc Returns the number of rows that  *
     *  are on the last mySQL query.          *
     ******************************************/
    function num_rows($res = "") {
        $res = (!isset($res) || empty($res)) ? $this->result : $res;
        if ($r = @mysql_num_rows($res)) {
            return $r;
        } else {
            $this->error = 1;
            $this->err_type = 2;
            $this->call_error();
        }
    }
 
    /*****************************************
     * @name escape_string                   *
     * @desc escapes a string to be used in  *
     *  a query                              *
     *****************************************/
    function escape_string($string, $dbi = false) {
        $dbi = ($dbi != false) ? $dbi : $this->sql_link;
        $string = mysql_real_escape_string($string, $this->sql_link);
        return $string;
    }

    /*****************************************
     * @name disconnect                      *
     * @desc Closes a mySQL connection       *
     *****************************************/
    function disconnect() {
        if ($this->pconnect == true) {
            return true;
        } else {
            return @mysql_close($this->sql_link);
        }
    }
}
?>
